@@ -321,8 +321,8 @@ class TorchTagger:
         for v in doc.values():
             combined_text.append(v)
         combined_text = " ".join(combined_text)
-        prediction_item, prediction_prob = self.tag_text(combined_text)
-        return self._process_prediction_output(prediction_item, prediction_prob)
+        result = self.tag_text(combined_text)
+        return result
 
 
     @staticmethod
